summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmphotonsedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmphotonsedit.h')
-rw-r--r--kpovmodeler/pmphotonsedit.h5
1 files changed, 3 insertions, 2 deletions
diff --git a/kpovmodeler/pmphotonsedit.h b/kpovmodeler/pmphotonsedit.h
index a4d3e414..c5950eb1 100644
--- a/kpovmodeler/pmphotonsedit.h
+++ b/kpovmodeler/pmphotonsedit.h
@@ -37,12 +37,13 @@ class TQLabel;
class PMPhotonsEdit : public PMDialogEditBase
{
Q_OBJECT
+ TQ_OBJECT
typedef PMDialogEditBase Base;
public:
/**
* Creates a PMPhotonsEdit with parent and name
*/
- PMPhotonsEdit( TQWidget* parent, const char* name = 0 );
+ PMPhotonsEdit( TQWidget* tqparent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -37,12 +37,13 @@ class TQLabel;
public:
/**
- * Creates a PMPhotonsEdit with parent and name
+ * Creates a PMPhotonsEdit with tqparent and name
*/